==> jc-1.4.0.tar.gz: java/security/cert/TrustAnchor.h <==
// public class java.security.cert.TrustAnchor

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a32f58fba5216297 java_security_cert_TrustAnchor

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_TrustAnchor_H_
#define _JC_java_security_cert_TrustAnchor_H_

// Forward structure declarations
struct _jc_gnu_java_security_x509_X500DistinguishedName$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_PublicKey$object;
struct _jc_java_security_cert_X509Certificate$object;

// Typedefs
typedef struct _jc_java_security_cert_TrustAnchor$sub_refs	_jc_java_security_cert_TrustAnchor$sub_refs;
typedef struct _jc_java_security_cert_TrustAnchor$sub_nonrefs	_jc_java_security_cert_TrustAnchor$sub_nonrefs;
typedef struct _jc_java_security_cert_TrustAnchor$refs	_jc_java_security_cert_TrustAnchor$refs;
typedef struct _jc_java_security_cert_TrustAnchor$nonrefs	_jc_java_security_cert_TrustAnchor$nonrefs;
typedef struct _jc_java_security_cert_TrustAnchor$object	_jc_java_security_cert_TrustAnchor$object;

typedef const struct _jc_java_security_cert_TrustAnchor$vmethods	_jc_java_security_cert_TrustAnchor$vmethods;
typedef const struct _jc_java_security_cert_TrustAnchor$vtable	_jc_java_security_cert_TrustAnchor$vtable;
typedef const struct _jc_java_security_cert_TrustAnchor$vtype	_jc_java_security_cert_TrustAnchor$vtype;

// Constructors
extern void _jc_java_security_cert_TrustAnchor$method$_init$d01a7764f4cced98(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_byte_array *);
extern void _jc_java_security_cert_TrustAnchor$method$_init$919e41fe54aa1eea(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *, struct _jc_java_security_cert_X509Certificate$object *, struct _jc_byte_array *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_security_cert_TrustAnchor$method$getCAName$c60c8f9901d93169(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *);
extern struct _jc_object *_jc_java_security_cert_TrustAnchor$method$getCAPublicKey$f331c3a4bc8a89d3(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *);
extern _jc_byte_array *_jc_java_security_cert_TrustAnchor$method$getNameConstraints$22b51b9830b47378(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *);
extern struct _jc_java_security_cert_X509Certificate$object *_jc_java_security_cert_TrustAnchor$method$getTrustedCert$e05f71051cc418a6(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_cert_TrustAnchor$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_TrustAnchor$method_info$getCAName$c60c8f9901d93169;
extern _jc_method _jc_java_security_cert_TrustAnchor$method_info$getCAPublicKey$f331c3a4bc8a89d3;
extern _jc_method _jc_java_security_cert_TrustAnchor$method_info$getNameConstraints$22b51b9830b47378;
extern _jc_method _jc_java_security_cert_TrustAnchor$method_info$getTrustedCert$e05f71051cc418a6;
extern _jc_method _jc_java_security_cert_TrustAnchor$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_TrustAnchor$vmethods {
	struct _jc_java_lang_String$object	*(*getCAName$c60c8f9901d93169)(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *);
	struct _jc_object	*(*getCAPublicKey$f331c3a4bc8a89d3)(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *);
	_jc_byte_array	*(*getNameConstraints$22b51b9830b47378)(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *);
	struct _jc_java_security_cert_X509Certificate$object	*(*getTrustedCert$e05f71051cc418a6)(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *);
};

// Vtable
struct _jc_java_security_cert_TrustAnchor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_TrustAnchor$vmethods	java_security_cert_TrustAnchor;
};

// Vtype
struct _jc_java_security_cert_TrustAnchor$vtype {
	_jc_type			type;
	_jc_java_security_cert_TrustAnchor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_TrustAnchor$sub_refs {
	struct _jc_gnu_java_security_x509_X500DistinguishedName$object	*caName;
	struct _jc_object	*caKey;
	struct _jc_java_security_cert_X509Certificate$object	*trustedCert;
	_jc_byte_array	*nameConstraints;
};

// Reference instance fields (object)
struct _jc_java_security_cert_TrustAnchor$refs {
    _jc_java_security_cert_TrustAnchor$sub_refs	java_security_cert_TrustAnchor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_TrustAnchor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_TrustAnchor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_TrustAnchor$sub_nonrefs	java_security_cert_TrustAnchor;
};

// Object instance structure
struct _jc_java_security_cert_TrustAnchor$object {
	_jc_java_security_cert_TrustAnchor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_TrustAnchor$vtype	*vtype;
	_jc_java_security_cert_TrustAnchor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_TrustAnchor$vtype _jc_java_security_cert_TrustAnchor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_TrustAnchor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_TrustAnchor$class_object;

#endif	/* _JC_java_security_cert_TrustAnchor_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/TrustAnchor.h <==
// public class java.security.cert.TrustAnchor

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a32f58fba5216297 java_security_cert_TrustAnchor

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_TrustAnchor_H_
#define _JC_java_security_cert_TrustAnchor_H_

// Forward structure declarations
struct _jc_gnu_java_security_x509_X500DistinguishedName$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_PublicKey$object;
struct _jc_java_security_cert_X509Certificate$object;

// Typedefs
typedef struct _jc_java_security_cert_TrustAnchor$sub_refs	_jc_java_security_cert_TrustAnchor$sub_refs;
typedef struct _jc_java_security_cert_TrustAnchor$sub_nonrefs	_jc_java_security_cert_TrustAnchor$sub_nonrefs;
typedef struct _jc_java_security_cert_TrustAnchor$refs	_jc_java_security_cert_TrustAnchor$refs;
typedef struct _jc_java_security_cert_TrustAnchor$nonrefs	_jc_java_security_cert_TrustAnchor$nonrefs;
typedef struct _jc_java_security_cert_TrustAnchor$object	_jc_java_security_cert_TrustAnchor$object;

typedef const struct _jc_java_security_cert_TrustAnchor$vmethods	_jc_java_security_cert_TrustAnchor$vmethods;
typedef const struct _jc_java_security_cert_TrustAnchor$vtable	_jc_java_security_cert_TrustAnchor$vtable;
typedef const struct _jc_java_security_cert_TrustAnchor$vtype	_jc_java_security_cert_TrustAnchor$vtype;

// Constructors
extern void _jc_java_security_cert_TrustAnchor$method$_init$d01a7764f4cced98(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_java_security_cert_TrustAnchor$method$_init$919e41fe54aa1eea(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *, struct _jc_java_security_cert_X509Certificate$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_security_cert_TrustAnchor$method$getCAName$c60c8f9901d93169(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_security_cert_TrustAnchor$method$getCAPublicKey$f331c3a4bc8a89d3(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_java_security_cert_TrustAnchor$method$getNameConstraints$22b51b9830b47378(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_cert_X509Certificate$object *_jc_java_security_cert_TrustAnchor$method$getTrustedCert$e05f71051cc418a6(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_cert_TrustAnchor$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_TrustAnchor$method_info$getCAName$c60c8f9901d93169;
extern _jc_method _jc_java_security_cert_TrustAnchor$method_info$getCAPublicKey$f331c3a4bc8a89d3;
extern _jc_method _jc_java_security_cert_TrustAnchor$method_info$getNameConstraints$22b51b9830b47378;
extern _jc_method _jc_java_security_cert_TrustAnchor$method_info$getTrustedCert$e05f71051cc418a6;
extern _jc_method _jc_java_security_cert_TrustAnchor$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_TrustAnchor$vmethods {
	struct _jc_java_lang_String$object	*(*getCAName$c60c8f9901d93169)(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getCAPublicKey$f331c3a4bc8a89d3)(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getNameConstraints$22b51b9830b47378)(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *) _JC_JCNI_ATTR;
	struct _jc_java_security_cert_X509Certificate$object	*(*getTrustedCert$e05f71051cc418a6)(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_TrustAnchor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_TrustAnchor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_TrustAnchor$vmethods	java_security_cert_TrustAnchor;
};

// Vtype
struct _jc_java_security_cert_TrustAnchor$vtype {
	_jc_type			type;
	_jc_java_security_cert_TrustAnchor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_TrustAnchor$sub_refs {
	struct _jc_gnu_java_security_x509_X500DistinguishedName$object	*caName;
	struct _jc_object	*caKey;
	struct _jc_java_security_cert_X509Certificate$object	*trustedCert;
	_jc_byte_array	*nameConstraints;
};

// Reference instance fields (object)
struct _jc_java_security_cert_TrustAnchor$refs {
    _jc_java_security_cert_TrustAnchor$sub_refs	java_security_cert_TrustAnchor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_TrustAnchor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_TrustAnchor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_TrustAnchor$sub_nonrefs	java_security_cert_TrustAnchor;
};

// Object instance structure
struct _jc_java_security_cert_TrustAnchor$object {
	_jc_java_security_cert_TrustAnchor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_TrustAnchor$vtype	*vtype;
	_jc_java_security_cert_TrustAnchor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_TrustAnchor$vtype _jc_java_security_cert_TrustAnchor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_TrustAnchor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_TrustAnchor$class_object;

#endif	/* _JC_java_security_cert_TrustAnchor_H_ */
